@@ -13,14 +13,18 @@ function(x,cluster=NULL, defuzzify=FALSE,...) {
 	}
   }
    if(inherits(x,"vegclust")||inherits(x,"vegclass")){
-		k = length(names(x$dist2clusters))
-		v = vector("numeric",k)
-		if(defuzzify) memb = defuzzify(x, ...)$memb
-		else memb = x$memb
-   	for(i in 1:k) {
-   		v[i] = sum((x$dist2clusters[,i]^2)*(memb[,i]^x$m))
-   		v[i] = v[i]/sum(memb[,i]^x$m)
-   	}
+     if(defuzzify) memb = defuzzify(x, ...)$memb
+     else memb = x$memb
+     k = length(names(x$dist2clusters))
+		 v = vector("numeric",k)
+   	 for(i in 1:k) {
+   	   if(x$method=="KMdd"||x$method=="FCMdd"||x$method=="NCdd"||x$method=="PCMdd"||x$method=="HNCdd") {
+   	     v[i] = sum((x$dist2clusters[,i])*(memb[,i]^x$m)) #Distances to medoid weighted by membership
+   	   } else {
+   	     v[i] = sum((x$dist2clusters[,i]^2)*(memb[,i]^x$m)) #Squared distances to centroid weighted by membership
+   	   }
+   		 v[i] = v[i]/sum(memb[,i]^x$m)
+   	 }
 		names(v) = names(x$dist2clusters)
 		return(v)		   	
    } else if(is.null(cluster)) {
